@@ -4,4 +4,6 @@
 '''
 from .flybys import *
 from .environments import *
-from .tools import *
\ No newline at end of file
+from .tools import *
+from .analytic import *
+__version__ = '0.3.0'
\ No newline at end of file
